@@ -1,13 +1,18 @@
 
 from __future__ import print_function
 
-import sys, wx, wx.lib, wx.combo, os, re, pickle, traceback, json
+import sys, wx, wx.lib, os, re, pickle, traceback, json
 from wx.lib.scrolledpanel import ScrolledPanel
 from types import *
 # Quisk will alter quisk_conf_defaults to include the user's config file.
 import quisk_conf_defaults as conf
 import _quisk as QS
 from quisk_widgets import QuiskBitField
+from quisk_widgets import wxVersion
+if wxVersion in ('2', '3'):
+  import wx.combo as wxcombo
+else:
+  wxcombo = wx                  # wxPython Phoenix
 
 # Settings is [
 #   0: radio_requested, a string radio name or "Ask me" or "ConfigFileRadio"
@@ -86,6 +91,8 @@ class Configuration:
       if k == 'favorites_file_path':	# A null string is equivalent to "not entered"
         if not v.strip():
           continue
+      if k == 'power_meter_local_calibrations':	# present in configuration data but not in the config file
+        continue
       try:
         fmt = self.format4name[k]
       except:
@@ -119,6 +126,13 @@ class Configuration:
             setattr(conf, k, False)
         elif fmt4 == 'rfil':
           pass
+        elif fmt4 == 'keyc':	# key code
+          if v == "None":
+            setattr(conf, k, None)
+          else:
+            x = eval(v)
+            x = int(x)
+            setattr(conf, k, x)
         else:
           print ("Unknown format for", k, fmt)
       except:
@@ -380,7 +394,7 @@ class Configuration:
       elif line[0:17] == '################ ':
         args = line[17:].split(None, 2)
         section = args[0]
-        if section in ('Keys', 'Colors', 'Obsolete'):
+        if section in ('Colors', 'Obsolete'):
           section = None
           continue
         rxname = None
@@ -434,11 +448,139 @@ class ConfigHelp(wx.html.HtmlWindow):	# The "Help with Radios" first-level page
     # read in text from file help_conf.html in the directory of this module
     self.LoadFile('help_conf.html')
 
+class QPowerMeterCalibration(wx.Frame):
+  """Create a window to enter the power output and corresponding ADC value AIN1/2"""
+  def __init__(self, parent, local_names):
+    self.parent = parent
+    self.local_names = local_names
+    self.table = []	# calibration table: list of [ADC code, power watts]
+    try:	# may be missing in wxPython 2.x
+      wx.Frame.__init__(self, application.main_frame, -1, "Power Meter Calibration",
+         pos=(50, 100), style=wx.CAPTION|wx.FRAME_FLOAT_ON_PARENT)
+    except AttributeError:
+      wx.Frame.__init__(self, application.main_frame, -1, "Power Meter Calibration",
+         pos=(50, 100), style=wx.CAPTION)
+    panel = wx.Panel(self)
+    self.MakeControls(panel)
+    self.Show()
+  def MakeControls(self, panel):
+    charx = panel.GetCharWidth()
+    tab1 = charx * 5
+    y = 20
+    # line 1
+    txt = wx.StaticText(panel, -1, 'Name for new calibration table', pos=(tab1, y))
+    w, h = txt.GetSize().Get()
+    tab2 = tab1 + w + tab1 // 2
+    self.cal_name = wx.TextCtrl(panel, -1, pos=(tab2, h), size=(charx * 16, h * 13 // 10))
+    y += h * 3
+    # line 2
+    txt = wx.StaticText(panel, -1, 'Measured power level in watts', pos=(tab1, y))
+    self.cal_power = wx.TextCtrl(panel, -1, pos=(tab2, y), size=(charx * 16, h * 13 // 10))
+    x = tab2 + charx * 20
+    add = wx.lib.buttons.GenButton(panel, -1, 'Add to Table', pos=(x, y - h * 3 // 10))
+    ww, hh = add.GetSize().Get()
+    width = x + ww + tab1
+    add.Bind(wx.EVT_BUTTON, self.OnBtnAdd)
+    add.SetBezelWidth(2)
+    add.SetUseFocusIndicator(False)
+    y += h * 3
+    # line 3
+    sv = wx.lib.buttons.GenButton(panel, -1, 'Save')
+    sv.Bind(wx.EVT_BUTTON, self.OnBtnSave)
+    sv.SetBezelWidth(2)
+    sv.SetUseFocusIndicator(False)
+    cn = wx.lib.buttons.GenButton(panel, -1, 'Cancel')
+    cn.Bind(wx.EVT_BUTTON, self.OnBtnCancel)
+    cn.SetBezelWidth(2)
+    cn.SetUseFocusIndicator(False)
+    w, h = cn.GetSize().Get()
+    sv.SetPosition((width // 4, y))
+    cn.SetPosition((width - width // 4 - w, y))
+    y += h * 12 // 10
+    # help text at bottom
+    wx.StaticText(panel, -1, '1. Attach a 50 ohm load and power meter to the antenna connector.', pos=(tab1, y))
+    w, h = txt.GetSize().Get()
+    h = h * 12 // 10
+    y += h
+    wx.StaticText(panel, -1, '2. Use the Spot button to transmit at a very low power.', pos=(tab1, y))
+    y += h
+    wx.StaticText(panel, -1, '3. Enter the measured power in the box above and press "Add to Table".', pos=(tab1, y))
+    y += h
+    wx.StaticText(panel, -1, '4. Increase the power a small amount and repeat step 3.', pos=(tab1, y))
+    y += h
+    wx.StaticText(panel, -1, '5. Increase power again and repeat step 3.', pos=(tab1, y))
+    y += h
+    wx.StaticText(panel, -1, '6. Keep adding measurements to the table until you reach full power.', pos=(tab1, y))
+    y += h
+    wx.StaticText(panel, -1, '7. Ten or twelve measurements should be enough. Then press "Save".', pos=(tab1, y))
+    y += h
+    wx.StaticText(panel, -1, 'To delete a table, save a table with zero measurements.', pos=(tab1, y))
+    y += h * 2
+    self.SetClientSize(wx.Size(width, y))
+  def OnBtnCancel(self, event=None):
+    self.parent.ChangePMcalFinished(None, None)
+    self.Destroy()
+  def OnBtnSave(self, event):
+    name = self.cal_name.GetValue().strip()
+    if not name:
+      dlg = wx.MessageDialog(self,
+        'Please enter a name for the new calibration table.',
+        'Missing Name', wx.OK|wx.ICON_ERROR)
+      dlg.ShowModal()
+      dlg.Destroy()
+    elif name in conf.power_meter_std_calibrations.keys():		# known calibration names from the config file
+      dlg = wx.MessageDialog(self,
+        'That name is reserved. Please enter a different name.',
+        'Reserved Name', wx.OK|wx.ICON_ERROR)
+      dlg.ShowModal()
+      dlg.Destroy()
+    elif name in self.local_names:
+      if self.table:
+        dlg = wx.MessageDialog(self,
+          'That name exists. Replace the existing table?',
+          'Replace Table', wx.OK|wx.CANCEL|wx.ICON_EXCLAMATION)
+        ret = dlg.ShowModal()
+        dlg.Destroy()
+        if ret == wx.ID_OK:
+          self.parent.ChangePMcalFinished(name, self.table)
+          self.Destroy()
+      else:
+        dlg = wx.MessageDialog(self,
+          'That name exists but the table is empty. Delete the existing table?.',
+          'Delete Table', wx.OK|wx.CANCEL|wx.ICON_EXCLAMATION)
+        ret = dlg.ShowModal()
+        dlg.Destroy()
+        if ret == wx.ID_OK:
+          self.parent.ChangePMcalFinished(name, None)
+          self.Destroy()
+    else:
+      self.parent.ChangePMcalFinished(name, self.table)
+      self.Destroy()
+  def OnBtnAdd(self, event):
+    power = self.cal_power.GetValue().strip()
+    self.cal_power.Clear()
+    try:
+      power = float(power)
+    except:
+      dlg = wx.MessageDialog(self, 'Missing or bad measured power.', 'Error in Power', wx.OK|wx.ICON_ERROR)
+      dlg.ShowModal()
+      dlg.Destroy()
+    else:
+      ## Convert measured voltage to power
+      #power *= 6.388
+      #power = power**2 / 50.0
+      fwd = application.Hardware.hermes_fwd_power
+      rev = application.Hardware.hermes_rev_power
+      if fwd >= rev:
+        self.table.append([fwd, power])		# Item must use lists; sort() will fail with mixed lists and tuples
+      else:
+        self.table.append([rev, power])
+
 class RadioNotebook(wx.Notebook):	# The second-level notebook for each radio name
   def __init__(self, parent, radio_name):
     wx.Notebook.__init__(self, parent)
     font = wx.Font(conf.config_font_size, wx.FONTFAMILY_SWISS, wx.NORMAL,
-          wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+          wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     self.SetFont(font)
     self.radio_name = radio_name
     self.pages = []
@@ -466,16 +608,16 @@ class RadioNotebook(wx.Notebook):	# The second-level notebook for each radio nam
     for page in self.pages:
       page.radio_name = new_name
 
-class ComboCtrl(wx.combo.ComboCtrl):
+class ComboCtrl(wxcombo.ComboCtrl):
   def __init__(self, parent, value, choices, no_edit=False):
     self.value = value
     self.choices = choices[:]
     self.handler = None
     self.height = parent.quisk_height
     if no_edit:
-      wx.combo.ComboCtrl.__init__(self, parent, -1, style=wx.CB_READONLY)
+      wxcombo.ComboCtrl.__init__(self, parent, -1, style=wx.CB_READONLY)
     else:
-      wx.combo.ComboCtrl.__init__(self, parent, -1, style=wx.TE_PROCESS_ENTER)
+      wxcombo.ComboCtrl.__init__(self, parent, -1, style=wx.TE_PROCESS_ENTER)
       self.GetTextCtrl().Bind(wx.EVT_KILL_FOCUS, self.OnKillFocus)
       self.Bind(wx.EVT_TEXT_ENTER, self.OnTextEnter)
     self.ctrl = ListBoxComboPopup(choices, parent.font)
@@ -521,9 +663,9 @@ class ComboCtrl(wx.combo.ComboCtrl):
   def OnListbox(self):
     self.OnTextEnter()
 
-class ListBoxComboPopup(wx.ListBox, wx.combo.ComboPopup):
+class ListBoxComboPopup(wxcombo.ComboPopup):
   def __init__(self, choices, font):
-    wx.combo.ComboPopup.__init__(self)
+    wxcombo.ComboPopup.__init__(self)
     self.choices = choices
     self.font = font
     self.lbox = None
@@ -550,7 +692,10 @@ class ListBoxComboPopup(wx.ListBox, wx.combo.ComboPopup):
   def OnLeftDown(self, event):
     event.Skip()
     self.Dismiss()
-    self.GetCombo().OnListbox()
+    if wxVersion in ('2', '3'):
+      self.GetCombo().OnListbox()
+    else:
+      self.GetComboCtrl().OnListbox()
   def OnMotion(self, event):
     event.Skip()
     item = self.lbox.HitTest(event.GetPosition())
@@ -563,7 +708,7 @@ class BaseWindow(ScrolledPanel):
   def __init__(self, parent):
     ScrolledPanel.__init__(self, parent)
     self.font = wx.Font(conf.config_font_size, wx.FONTFAMILY_SWISS, wx.NORMAL,
-          wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+          wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     self.SetFont(self.font)
     self.row = 1
     self.charx = self.GetCharWidth()
@@ -760,18 +905,22 @@ class BaseWindow(ScrolledPanel):
       radio_dict[name] = value
       local_conf.settings_changed = True
       # Immediate changes
-      if name == 'hermes_lowpwr_tr_enable':
-        value = (value == "True")
-        application.Hardware.SetLowPwrEnable(value)
-      elif name == 'hermes_power_amp':
-        value = (value == "True")
-        application.Hardware.EnablePowerAmp(value)
-      elif name == "hermes_bias_adjust":
-        value = (value == "True")
-        self.HermesBias0.Enable(value)
-        self.HermesBias1.Enable(value)
-        self.HermesWriteBiasButton.Enable(value)
-        application.Hardware.EnableBiasChange(value)
+      if self.radio_name == Settings[1]:	# changed for current radio
+        if name == 'hot_key_ptt_toggle':
+          x = eval(value)
+          setattr(conf, name, x)
+        elif name == 'hermes_lowpwr_tr_enable':
+          value = (value == "True")
+          application.Hardware.SetLowPwrEnable(value)
+        elif name == 'hermes_power_amp':
+          value = (value == "True")
+          application.Hardware.EnablePowerAmp(value)
+        elif name == "hermes_bias_adjust":
+          value = (value == "True")
+          self.HermesBias0.Enable(value)
+          self.HermesBias1.Enable(value)
+          self.HermesWriteBiasButton.Enable(value)
+          application.Hardware.EnableBiasChange(value)
   def FormatOK(self, value, fmt4):		# Check formats integer and number
     i1 = value.find('#')
     try:
@@ -1015,6 +1164,7 @@ class RadioHardware(BaseWindow):		# The Hardware page in the second-level notebo
     BaseWindow.__init__(self, parent)
     self.radio_name = radio_name
     self.num_cols = 8
+    self.PMcalDialog = None
     #self.MarkCols()
     radio_dict = local_conf.GetRadioDict(radio_name)
     radio_type = radio_dict['hardware_file_type']
@@ -1051,8 +1201,14 @@ class RadioHardware(BaseWindow):		# The Hardware page in the second-level notebo
       else:
         value = self.GetValue(name, radio_dict)
         no_edit = "choice" in fmt or fmt == 'boolean'
-        txt, cb, btn = self.AddTextComboHelp(col, text, value, values, help_text, no_edit, border=border)
-        cb.handler = self.OnChange
+        if name == 'power_meter_calib_name':
+          values = self.PowerMeterCalChoices()
+          txt, cb, btn = self.AddTextComboHelp(col, text, value, values, help_text, no_edit, border=border)
+          cb.handler = self.OnButtonChangePMcal
+          self.power_meter_cal_choices = cb
+        else:
+          txt, cb, btn = self.AddTextComboHelp(col, text, value, values, help_text, no_edit, border=border)
+          cb.handler = self.OnChange
         cb.quisk_data_name = name
         if col == 1:
           col = 4
@@ -1125,6 +1281,51 @@ class RadioHardware(BaseWindow):		# The Hardware page in the second-level notebo
     value0 = self.HermesBias0.GetValue()
     value1 = self.HermesBias1.GetValue()
     application.Hardware.WriteBias(value0, value1)
+  def PowerMeterCalChoices(self):
+    values = conf.power_meter_std_calibrations.keys()		# known calibration names from the config file
+    radio_dict = local_conf.GetRadioDict(self.radio_name)
+    values += radio_dict.get('power_meter_local_calibrations', {}).keys()		# local calibrations
+    values.sort()
+    values.append('New')
+    return values
+  def OnButtonChangePMcal(self, ctrl):
+    value = ctrl.GetValue()
+    name = ctrl.quisk_data_name
+    radio_dict = local_conf.GetRadioDict(self.radio_name)
+    local_cal = radio_dict.get('power_meter_local_calibrations', {})
+    if value == 'New':
+      if not self.PMcalDialog:
+        self.PMcalDialog = QPowerMeterCalibration(self, local_cal.keys())
+    else:
+      setattr(conf, name, value)
+      radio_dict[name] = value
+      local_conf.settings_changed = True
+      application.Hardware.MakePowerCalibration()
+  def ChangePMcalFinished(self, name, table):
+    self.PMcalDialog = None
+    radio_dict = local_conf.GetRadioDict(self.radio_name)
+    local_cal = radio_dict.get('power_meter_local_calibrations', {})
+    if name is None:        # Cancel
+      name = conf.power_meter_calib_name
+      values = self.PowerMeterCalChoices()
+    else:
+      if table is None:		# delete name
+        del local_cal[name]
+        name = conf.power_meter_std_calibrations.keys()[0]      # replacement name
+      else:     # new entry
+        local_cal[name] = table
+      conf.power_meter_calib_name = name
+      radio_dict['power_meter_calib_name'] = name
+      radio_dict['power_meter_local_calibrations'] = local_cal
+      local_conf.settings_changed = True
+      values = self.PowerMeterCalChoices()
+      self.power_meter_cal_choices.SetItems(values)
+      application.Hardware.MakePowerCalibration()
+    try:
+      index = values.index(name)
+    except:
+      index = 0
+    self.power_meter_cal_choices.SetSelection(index)
 
 
 class RadioSound(BaseWindow):		# The Sound page in the second-level notebook for each radio
