@@ -6,6 +6,7 @@ from __future__ import print_function
 
 import socket, traceback, time, math
 import _quisk as QS
+import quisk_utils
 
 from quisk_hardware_model import Hardware as BaseHardware
 
@@ -19,10 +20,10 @@ class Hardware(BaseHardware):
     self.hermes_ip = ""
     self.hermes_code_version = -1
     self.hermes_board_id = -1
-    self.hermes_temperature = 0
-    self.hermes_fwd_power = 0
-    self.hermes_rev_power = 0
-    self.hermes_pa_current = 0
+    self.hermes_temperature = 0.0
+    self.hermes_fwd_power = 0.0
+    self.hermes_rev_power = 0.0
+    self.hermes_pa_current = 0.0
     self.mode = None
     self.band = None
     self.vfo_frequency = 0
@@ -37,6 +38,11 @@ class Hardware(BaseHardware):
     self.repeater_time0 = 0			# time of repeater change in frequency
     # Create the proper broadcast address for rx_udp_ip.
     if False and self.conf.rx_udp_ip:
+      # get local IP address
+      s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+      s.connect(("8.8.8.8", 80))
+      ip = s.getsockname()[0]
+      #
       nm = self.conf.rx_udp_ip_netmask.split('.')
       ip = self.conf.rx_udp_ip.split('.')
       nm = map(int, nm)
@@ -62,6 +68,7 @@ class Hardware(BaseHardware):
       self.SetControlByte(c0, 2, 0x6B)
     self.SetLowPwrEnable(conf.hermes_lowpwr_tr_enable)
     self.EnablePowerAmp(conf.hermes_power_amp)
+    self.MakePowerCalibration()
   def pre_open(self):
     st = "No capture device found."
     port = self.conf.rx_udp_port
@@ -167,11 +174,7 @@ class Hardware(BaseHardware):
   def ReturnFrequency(self):	# Return the current tuning and VFO frequency
     return None, None			# frequencies have not changed
   def HeartBeat(self):
-    data = QS.hermes_to_pc()
-    self.hermes_temperature = data[4] << 8 | data[5]
-    self.hermes_fwd_power   = data[6] << 8 | data[7]
-    self.hermes_rev_power   = data[8] << 8 | data[9]
-    self.hermes_pa_current  = data[10] << 8 | data[11]
+    self.hermes_temperature, self.hermes_fwd_power, self.hermes_rev_power, self.hermes_pa_current = QS.get_hermes_TFRC()
     if self.application.bottom_widgets:
       self.application.bottom_widgets.UpdateText()
   def RepeaterOffset(self, offset=None):	# Change frequency for repeater offset during Tx
@@ -436,6 +439,38 @@ class Hardware(BaseHardware):
     self.pc2hermeslitewritequeue[0:5] = 0x7b,0x06,addr,0x00,data
     self.WriteQueue(1)
     if DEBUG: print ("Write AD9866 addr={0:06x} data={1:06x}".format(addr,data))
-
-
-
+  def MakePowerCalibration(self):
+    # Use spline interpolation to convert the ADC power sensor value to power in watts
+    name = self.conf.power_meter_calib_name
+    try:	# look in config file
+      table = self.conf.power_meter_std_calibrations[name]
+    except:
+      try:	# look in local name space
+        table = self.application.local_conf.GetRadioDict().get('power_meter_local_calibrations', {})[name]
+      except:	# not found
+        self.power_interpolator = None
+        return
+    if len(table) < 3:
+      self.power_interpolator = None
+      return
+    table.sort()
+    if table[0][0] > 0:		# Add zero code at zero power
+      table.insert(0, [0, 0.0])
+    # fill out the table to the maximum code 4095
+    l = len(table) - 1
+    x = table[l][0] * 1.1	# voltage increase
+    y = table[l][1] * 1.1**2	# square law power increase
+    while 1:
+      table.append([x, y])
+      if x > 4095:
+        break
+      x *= 1.1
+      y *= 1.1**2
+    self.power_interpolator = quisk_utils.SplineInterpolator(table)
+  def InterpolatePower(self, x):
+    if not self.power_interpolator:
+      return 0.0
+    y = self.power_interpolator.Interpolate(x)
+    if y < 0.0:
+      y = 0.0
+    return y
