@@ -908,10 +908,28 @@ static void transmit_udp(complex double * cSamples, int count)
 
 static void transmit_mic_carrier(complex double * cSamples, int count, double level)
 {	// send a CW carrier instead of mic samples
+#if 1
+	// transmit a carrier equal to the number of samples
 	int i;
-
-	for (i = 0; i < count; i++)		// transmit a carrier equal to the number of samples
+	for (i = 0; i < count; i++)
 		cSamples[i] = level * CLIP16;
+#else
+	// replace mic samples with a sin wave
+	int i;
+	double freq;
+	complex double phase1;		// Phase increment
+	static complex double vector1 = CLIP16 / 2;
+
+	// Use the sidetone slider 0 to 1000 to set frequency
+	freq = quisk_sidetoneCtrl * 5;
+	freq = ((int)freq / 50) * 50;
+	phase1 = cexp(I * 2.0 * M_PI * freq / 48000.0);
+	//phase1 = conj(phase1);
+	for (i = 0; i < count; i++) {
+		vector1 *= phase1;
+		cSamples[i] = vector1 * level;
+	}
+#endif
 }
 
 static void transmit_mic_imd(complex double * cSamples, int count, double level)
