@@ -526,7 +526,7 @@ class StationControlGUI(wx.Frame):    # Display a control window for my antenna
       self.filename = '/home/jim/pub/TunerLCZ.tmp'
     self.SetBackgroundColour('light steel blue')
     sizer = wx.GridBagSizer(hgap=5, vgap=3)
-    font = wx.Font(12, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+    font = wx.Font(12, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     row = 0
     szr = wx.BoxSizer(wx.HORIZONTAL)
     self.bands = []
@@ -583,7 +583,7 @@ class StationControlGUI(wx.Frame):    # Display a control window for my antenna
     sizer.Add(szr, pos=(row, 0), span=(1, 3))
     self.SetSizer(sizer)
     self.Fit()
-    w, h = self.GetSizeTuple()
+    w, h = self.GetSize().Get()
     self.SetSize((w, h + 20))
     self.Bind(wx.EVT_CLOSE, self.OnBtnClose)
     if parent is None:	# Start a HeartBeat if the parent does not provide one
