@@ -59,6 +59,9 @@ sample_rate = 48000					# name_of_sound_capt hardware sample rate in Hertz
 if sys.platform == "win32":
   name_of_sound_capt = "Primary"
   name_of_sound_play = "Primary"
+elif sys.platform == "darwin":
+  name_of_sound_capt = "pulse"
+  name_of_sound_play = "pulse"
 else:
   name_of_sound_capt = "hw:0"		# Name of soundcard capture hardware device.
   name_of_sound_play = "hw:0"
@@ -378,6 +381,24 @@ hermes_bias_adjust = False
 hermes_power_amp = False
 #hermes_power_amp = True
 
+## power_meter_calib_name		Power meter calibration, text choice
+# This is the calibration table used to convert the power sensor voltage measured by the ADC to the transmit power display.
+# It is a table of ADC codes and the corresponding measured power level.  If you have a power meter, you can create your own
+# table by selecting "New". Then enter ten or more power measurements from low to full power.
+# For the Hermes-Lite version E3 filter board, use the built-in table "HL2FilterE3".
+# Changes are immediate (no need to restart).
+power_meter_calib_name = 'HL2FilterE3'
+
+# These are known power meter calibration tables. This table is not present in the JSON settings file.
+power_meter_std_calibrations = {}
+power_meter_std_calibrations['HL2FilterE3'] = [[ 0, 0.0 ], [ 25.865384615384617, 0.0025502539351328003 ], [ 101.02453987730061, 0.012752044999999998 ], 
+          [ 265.2901234567901, 0.050600930690879994 ], [ 647.9155844155844, 0.21645831264800003 ], [ 1196.5935483870967, 0.66548046472992 ], 
+          [ 1603.7032258064517, 1.1557229391679997 ], [ 2012.3271604938273, 1.811892166688 ], [ 2616.7727272727275, 3.0085848760319993 ], 
+          [ 3173.818181818182, 4.3927428485119995 ], [ 3382.7922077922076, 4.9791328857920005 ], [ 3721.0714285714284, 6.024750791808321 ], 
+          [ 4093.1785714285716, 7.28994845808807 ], [ 4502.496428571429, 8.820837634286566 ], [ 4952.746071428572, 10.673213537486745 ] ]
+#power_meter_std_calibrations['HL2FilterE1'] = [[0, 0.0], [9.07, 0.002], [54.98, 0.014], [148.6, 0.057],
+#          [328.0, 0.208], [611.1, 0.646], [807.0, 1.098], [982.1, 1.6], [1223.3, 2.471], [1517.7, 3.738], [1758.7, 5.02]]
+
 ## Hermes_BandDict		Hermes Bus, dict
 # The Hermes_BandDict sets the 7 bits on the J16 connector.
 Hermes_BandDict = {
@@ -1166,26 +1187,35 @@ digital_xmlrpc_url = "http://localhost:7362"
 
 
 ################ Keys
-# You can define two hot keys that when pressed simultaneously, will push the PTT button.
-# If you want only one hot key, set hot_key_ptt2 to None.  Use any of the wx.WXK_* key codes,
-# or the ord() of the letter.  Do not choose hot keys that interfere with other features
-# on your system; for example, system menus or the frequency entry box.
+## hot_key_ptt1		PTT Key 1, keycode
+# Set a keyboard shortcut that will press the PTT button.
+# For a regular key, use the ord() of the key.  For example, ord('a') or ord('b').  For the space bar
+# use ord(' ').  Then restart Quisk.
+# If you do not want a hot key, set this to None.
+# Do not choose a key that interferes with other features
+# on your system such as system menus.
 hot_key_ptt1 = None
-hot_key_ptt2 = None
-#hot_key_ptt1 = wx.WXK_CONTROL
-#hot_key_ptt1 = wx.WXK_SHIFT
-#hot_key_ptt1 = wx.WXK_ALT
+#hot_key_ptt1 = ord(' ')
+#hot_key_ptt1 = ord('z')
+#hot_key_ptt1 = ord('a')
 #hot_key_ptt1 = wx.WXK_F5
-#hot_key_ptt2 = ord(' ')
-#hot_key_ptt2 = ord('A')
 
-# This determines what happens when you tune by dragging the mouse.  The correct
-# choice depends on how your hardware performs tuning.  You may want to use a
-# custom hardware file with a custom ChangeFrequency() method too.
-mouse_tune_method = 0	# The Quisk tune frequency changes and the VFO frequency is unchanged.
-#mouse_tune_method = 1	# The Quisk tune frequency is unchanged and the VFO changes.
-# configurable mouse wheel thanks to DG7MGY
-mouse_wheelmod = 50		# Round frequency when using mouse wheel (50 Hz)
+## hot_key_ptt2		PTT Key 2, keycode
+# If the Control or Shift key must be pressed too, set that key modifier here.
+# Otherwise, set None here.
+# For example, if you want control-A, set control in "PTT Key 2", and ord('a') in "PTT Key 1".
+# On some systems, control and shift may be reversed.
+hot_key_ptt2 = None
+#hot_key_ptt2 = wx.WXK_CONTROL
+#hot_key_ptt2 = wx.WXK_SHIFT
+
+## hot_key_ptt_toggle	PTT Key Toggle, boolean
+# Set to True if you want PTT to remain on when you release the key.  A second key press will
+# then release PTT.  This is toggle mode.  If False, you must keep pressing the key, and releasing
+# it will release PTT.
+# Changes are immediate (no need to restart).
+hot_key_ptt_toggle = False
+#hot_key_ptt_toggle = True
 
 
 
@@ -1996,4 +2026,12 @@ persistent_state = True
 default_mode = 'USB'
 # If you use a soundcard with Ethernet control of the VFO, set these parameters:
 rx_ip = ""							# Receiver IP address for VFO control
+# This determines what happens when you tune by dragging the mouse.  The correct
+# choice depends on how your hardware performs tuning.  You may want to use a
+# custom hardware file with a custom ChangeFrequency() method too.
+mouse_tune_method = 0	# The Quisk tune frequency changes and the VFO frequency is unchanged.
+#mouse_tune_method = 1	# The Quisk tune frequency is unchanged and the VFO changes.
+# configurable mouse wheel thanks to DG7MGY
+mouse_wheelmod = 50		# Round frequency when using mouse wheel (50 Hz)
+
 
