@@ -148,7 +148,7 @@ class GraphDisplay(wx.Window):
     self.backgroundPen = wx.Pen(self.GetBackgroundColour(), 1)
     self.horizPen = wx.Pen(conf.color_gl, 1, wx.SOLID)
     self.font = wx.Font(24, wx.FONTFAMILY_SWISS, wx.NORMAL,
-          wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+          wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     if sys.platform == 'win32':
       self.Bind(wx.EVT_ENTER_WINDOW, self.OnEnter)
   def OnEnter(self, event):
@@ -241,7 +241,7 @@ class GraphScreen(wx.Window):
     self.started = False
     self.doResize = False
     self.pen_tick = wx.Pen("Black", 1, wx.SOLID)
-    self.font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+    self.font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     self.SetFont(self.font)
     w = self.GetCharWidth() * 14 / 10
     h = self.GetCharHeight()
@@ -607,10 +607,10 @@ class GraphScreen(wx.Window):
     application.ShowFreq(freq, index)
   def GetMousePosition(self, event):
     """For mouse clicks in our display, translate to our screen coordinates."""
-    mouse_x, mouse_y = event.GetPositionTuple()
+    mouse_x, mouse_y = event.GetPosition()
     win = event.GetEventObject()
     if win is not self:
-      x, y = win.GetPositionTuple()
+      x, y = win.GetPosition().Get()
       mouse_x += x
       mouse_y += y
     return mouse_x, mouse_y
@@ -666,7 +666,7 @@ class Spacer(wx.Window):
     wx.Window.__init__(self, parent, pos = (0, 0),
        size=(-1, 6), style = wx.NO_BORDER)
     self.Bind(wx.EVT_PAINT, self.OnPaint)
-    r, g, b = parent.GetBackgroundColour().Get()
+    r, g, b = parent.GetBackgroundColour().Get(False)
     dark = (r * 7 / 10, g * 7 / 10, b * 7 / 10)
     light = (r + (255 - r) * 5 / 10, g + (255 - g) * 5 / 10, b + (255 - b) * 5 / 10)
     self.dark_pen = wx.Pen(dark, 1, wx.SOLID)
@@ -690,7 +690,7 @@ class CalibrateDialog(wx.Dialog):
     self.correct_open = None
     self.correct_short = None
     self.correct_load = None
-    w, h = app.main_frame.GetSizeTuple()
+    w, h = app.main_frame.GetSize().Get()
     width = w / 2
     if app.screen_name == "Reflection":
       title = "Calibrate for Reflection Mode"
@@ -720,7 +720,7 @@ class CalibrateDialog(wx.Dialog):
     tab = self.GetCharHeight() * 2
     y = tab
     txt = wx.StaticText(self, -1, t, pos=(tab, y))
-    z, chary = txt.GetSizeTuple()
+    z, chary = txt.GetSize().Get()
     y += chary * 3 / 2
     if app.screen_name == "Reflection":
       t = "To calibrate the VNA for reflection mode, connect the standard Short, Open and Load connectors to the unknown port, and press the button."
@@ -731,15 +731,15 @@ class CalibrateDialog(wx.Dialog):
     t += "  The calibration will be saved for use the next time the program starts."
     txt = wx.StaticText(self, -1, t, pos=(tab, y))
     txt.Wrap(width - tab * 2)
-    w, h = txt.GetSizeTuple()
+    w, h = txt.GetSize().Get()
     y += h + chary
     # Calibrate buttons
     t1 = wx.StaticText(self, -1, "Connect the Short connector and press", pos=(tab, y))
-    tw, th = t1.GetSizeTuple()
+    tw, th = t1.GetSize().Get()
     bx = tab + tw + tab / 2
     b1 = wx.lib.buttons.GenButton(self, -1, '  Short  ')
     self.Bind(wx.EVT_BUTTON, self.OnBtnShort, b1)
-    bw, bh = b1.GetSizeTuple()
+    bw, bh = b1.GetSize().Get()
     by = y + (th - bh) / 2
     b1.MoveXY(bx, by)
     self.txt_short = wx.StaticText(self, -1, "Not done", pos=(bx + bw + tab / 2, y))
@@ -760,7 +760,7 @@ class CalibrateDialog(wx.Dialog):
     # Calibrate buttons
     b1 = wx.lib.buttons.GenButton(self, -1, '  Calibrate  ')
     b1.Enable(False)
-    w, h = b1.GetSizeTuple()
+    w, h = b1.GetSize().Get()
     b2 = wx.lib.buttons.GenButton(self, -1, 'Cancel', size=(w, h))
     self.Bind(wx.EVT_BUTTON, self.OnBtnCalibrate, b1)
     self.Bind(wx.EVT_BUTTON, self.OnBtnCancel, b2)
@@ -768,7 +768,7 @@ class CalibrateDialog(wx.Dialog):
     b1.MoveXY(ww, y)
     b2.MoveXY(width - w - ww, y)
     y += h * 3 / 2
-    self.SetClientSizeWH(width, y)
+    self.SetClientSize(wx.Size(width, y))
     self.btns = [b1, b2]
     # timer for calibrate buttons
     self.calibrate_timer = wx.Timer(self)
@@ -1004,7 +1004,7 @@ class App(wx.App):
       if width < w:
         width = w
     for i in range(24, 8, -2):
-      font = wx.Font(i, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+      font = wx.Font(i, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
       frame.SetFont(font)
       w, h = frame.GetTextExtent('Start   ')
       if h < height * 9 / 10:
@@ -1076,8 +1076,8 @@ class App(wx.App):
       szr1.Add(x, 1, wx.RIGHT, gap)
     self.statusbar = self.main_frame.CreateStatusBar()
     # Set top window size
-    self.main_frame.SetClientSizeWH(self.graph.width, self.screen_height * 5 / 10)
-    w, h = self.main_frame.GetSizeTuple()
+    self.main_frame.SetClientSize(wx.Size(self.graph.width, self.screen_height * 5 / 10))
+    w, h = self.main_frame.GetSize().Get()
     self.main_frame.SetSizeHints(w, 1, w)
     if hasattr(Hardware, 'pre_open'):       # pre_open() is called before open()
       Hardware.pre_open()
@@ -1124,6 +1124,7 @@ class App(wx.App):
   def OnExit(self):
     QS.close_rx_udp()
     ##self.local_conf.SaveState()	# to save default radio selection
+    return 0
   def SaveState(self):
     if self.init_path:		# save current program state
       d = {}
