@@ -7,15 +7,23 @@ from types import *
 import quisk_conf_defaults as conf
 import _quisk as QS
 
+wxVersion = wx.version()[0]
+
+def EmptyBitmap(width, height):
+  if wxVersion in ('2', '3'):
+    return wx.EmptyBitmap(width, height)
+  else:
+    return wx.Bitmap(width, height)
+
 def MakeWidgetGlobals():
   global button_font, button_bezel, button_width, button_height, button_text_width, button_text_height
   global _bitmap_menupop, _bitmap_sliderpop, _bitmap_cyclepop
   button_bezel = 3		# size of button bezel in pixels
   button_font = wx.Font(conf.button_font_size, wx.FONTFAMILY_SWISS, wx.NORMAL,
-           wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+           wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
   dc = wx.MemoryDC()
   dc.SetFont(button_font)
-  tmp_bm = wx.EmptyBitmap(1, 1)		# Thanks to NS4Y
+  tmp_bm = EmptyBitmap(1, 1)		# Thanks to NS4Y
   dc.SelectObject(tmp_bm)
   button_text_width, button_text_height = dc.GetTextExtent('0')
   button_width = button_text_width + 2 + 2 * button_bezel # + 4 * int(self.useFocusInd)
@@ -23,7 +31,7 @@ def MakeWidgetGlobals():
   # Make a bitmap for the slider pop button
   height = button_text_height + 2	# button height less bezel
   width = height
-  _bitmap_sliderpop = wx.EmptyBitmap(height, height)
+  _bitmap_sliderpop = EmptyBitmap(height, height)
   dc.SelectObject(_bitmap_sliderpop)
   pen = wx.Pen(conf.color_enable, 1)
   dc.SetPen(pen)
@@ -59,7 +67,7 @@ def MakeWidgetGlobals():
   dc.DrawLine(x0 - 2, y0, x0 + 3, y0)
   dc.SelectObject(wx.NullBitmap)
   # Make a bitmap for the menu pop button
-  _bitmap_menupop = wx.EmptyBitmap(height, height)
+  _bitmap_menupop = EmptyBitmap(height, height)
   dc.SelectObject(_bitmap_menupop)
   dc.SetBackground(brush)
   dc.Clear()
@@ -71,7 +79,7 @@ def MakeWidgetGlobals():
     dc.DrawLine(x + 5, y + 1, width - 3, y + 1)
   dc.SelectObject(wx.NullBitmap)
   # Make a bitmap for the cycle button
-  _bitmap_cyclepop = wx.EmptyBitmap(height, height)
+  _bitmap_cyclepop = EmptyBitmap(height, height)
   dc.SelectObject(_bitmap_cyclepop)
   dc.SetBackground(brush)
   dc.SetFont(button_font)
@@ -106,7 +114,7 @@ class FrequencyDisplay(wx.lib.stattext.GenStaticText):
          style=wx.ALIGN_CENTER|wx.ST_NO_AUTORESIZE)
     border = 4
     for points in range(30, 6, -1):
-      font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+      font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
       self.SetFont(font)
       w, h = self.GetTextExtent('333 444 555 Hz')
       if w < width and h < height - border * 2:
@@ -260,7 +268,7 @@ class SliderBoxHH(SliderBoxH, wx.BoxSizer):
   def __init__(self, parent, text, init, themin, themax, handler, display):
     wx.BoxSizer.__init__(self, wx.HORIZONTAL)
     SliderBoxH.__init__(self, parent, text, init, themin, themax, handler, display, None, None)
-    #font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+    #font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     #self.text_ctrl.SetFont(font)
     self.Add(self.text_ctrl, 0, wx.ALIGN_CENTER)
     self.Add(self.slider, 1, wx.ALIGN_CENTER)
@@ -327,9 +335,9 @@ class QuiskText1(wx.lib.stattext.GenStaticText):
     # Set decreasing point size until size_text fits in the space available
     for points in range(20, 6, -1):
       if self.fixed:
-        font = wx.Font(points, wx.FONTFAMILY_MODERN, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+        font = wx.Font(points, wx.FONTFAMILY_MODERN, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
       else:
-        font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+        font = wx.Font(points, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
       dc.SetFont(font)
       w, h = dc.GetTextExtent(self.size_text)
       if w < width and h < height:
@@ -627,7 +635,7 @@ class QuiskBitField(wx.Window):
       if self.value & (1 << power):
         dc.DrawText('1', x, 0)
   def OnLeftDown(self, event):
-    mouse_x, mouse_y = event.GetPositionTuple()
+    mouse_x, mouse_y = event.GetPosition().Get()
     for index in range(len(self.linex)):
       if mouse_x < self.linex[index]:
         break
@@ -663,8 +671,8 @@ class QFilterButtonWindow(wx.Frame):
         incr = 500
       elif bw == 10000:
         incr = 1000
-    x, y = wrap.GetPositionTuple()
-    x, y = wrap.GetParent().ClientToScreenXY(x, y)
+    x, y = wrap.GetPosition().Get()
+    x, y = wrap.GetParent().ClientToScreen(wx.Point(x, y))
     w, h = wrap.GetSize()
     height = h * 10
     size = (w, height)
@@ -704,8 +712,8 @@ class QSliderButtonWindow(wx.Frame):
   """Create a window with controls for the button"""
   def __init__(self, button, value):
     self.button = button
-    x, y = button.GetPositionTuple()
-    x, y = button.GetParent().ClientToScreenXY(x, y)
+    x, y = button.GetPosition().Get()
+    x, y = button.GetParent().ClientToScreen(wx.Point(x, y))
     w, h = button.GetSize()
     height = h * 10
     size = (w, height)
@@ -741,8 +749,8 @@ class QDualSliderButtonWindow(wx.Frame):	# Thanks to Steve, KF7O
   """Create a window with controls for the button"""
   def __init__(self, button):
     self.button = button
-    x, y = button.GetPositionTuple()
-    x, y = button.GetParent().ClientToScreenXY(x, y)
+    x, y = button.GetPosition().Get()
+    x, y = button.GetParent().ClientToScreen(wx.Point(x, y))
     w, h = button.GetSize()
     w = w * 12 / 10
     height = h * 10
@@ -911,7 +919,7 @@ class WrapDualSlider(WrapControl):	# Thanks to Steve, KF7O
     ## It would be better if _bitmap_sliderpop were not a global variable 
     ##but a first-class member in another module
     _bitmap_sliderpop = MakeWidgetGlobals.__globals__['_bitmap_sliderpop']
-    b = QuiskBitmapButton(button.GetParent(), self.OnPopButton, _bitmap_sliderpop) ##wx.EmptyBitmap(10,10))
+    b = QuiskBitmapButton(button.GetParent(), self.OnPopButton, _bitmap_sliderpop)
     self.Add(b, 0, flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.LEFT, border=2)
   def OnPopButton(self, event):
     if self.adjust:
@@ -1132,9 +1140,9 @@ class RadioBtnPopup:
     if self.RbDialog.IsShown():
       self.RbDialog.Hide()
       return
-    dw, dh = self.RbDialog.GetSizeTuple()
-    bw, bh = self.first_button.GetSizeTuple()
-    bx, by = self.first_button.ClientToScreen((0, 0))
+    dw, dh = self.RbDialog.GetSize().Get()
+    bw, bh = self.first_button.GetSize().Get()
+    bx, by = self.first_button.ClientToScreen(wx.Point(0, 0))
     self.RbDialog.Position(wx.Point(bx + bw * 8 // 10, by + bh // 2 - dh), wx.Size(1, 1))
     self.RbDialog.Show()
     self.RbDialog.SetFocus()
@@ -1216,7 +1224,7 @@ class RadioBtnPopup:
       event.SetEventObject(self.first_button)
       command(event)
   def GetPositionTuple(self):
-    return self.first_button.GetPositionTuple()
+    return self.first_button.GetPosition().Get()
   def GetParent(self):
     return self.parent
   def GetSize(self):
@@ -1229,21 +1237,21 @@ class FreqSetter(wx.TextCtrl):
     self.fmin = fmin
     self.fmax = fmax
     self.command = command
-    self.font = wx.Font(16, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, face=conf.quisk_typeface)
+    self.font = wx.Font(16, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     t = wx.StaticText(parent, -1, label, pos=(x, y))
     t.SetFont(self.font)
     freq_w, freq_h = t.GetTextExtent(" 662 000 000")
-    tw, th = t.GetSizeTuple()
+    tw, th = t.GetSize().Get()
     x += tw + 20
     wx.TextCtrl.__init__(self, parent, size=(freq_w, freq_h), pos=(x, y),
       style=wx.TE_RIGHT|wx.TE_PROCESS_ENTER)
     self.SetFont(self.font)
     self.Bind(wx.EVT_TEXT, self.OnText)
     self.Bind(wx.EVT_TEXT_ENTER, self.OnEnter)
-    w, h = self.GetSizeTuple()
+    w, h = self.GetSize().Get()
     x += w + 1
     self.butn = b = wx.SpinButton(parent, size=(freq_h, freq_h), pos=(x, y))
-    w, h = b.GetSizeTuple()
+    w, h = b.GetSize().Get()
     self.end_pos = (x + w, y + h)
     b.Bind(wx.EVT_SPIN, self.OnSpin)	# The spin button frequencies are in kHz
     b.SetMin(fmin / 1000)
